documentFactory.RemoteDocumentStream

|  | ## Cheshire3 Object Model: Class RemoteDocumentStream

Module documentFactory :: Class RemoteDocumentStream

## Class RemoteDocumentStream
source code

Object Tree:

    BaseDocumentStream --+
                         |
                        RemoteDocumentStream

Known Subclasses:
  FtpDocumentStream, SQLDocumentStream, SrbDocumentStream, Z3950DocumentStream

Instance Methods

parse_url(self, url)
Inherited from `BaseDocumentStream`: `__init__`, `fetch_document`, `open_stream`

Class Variables

Inherited from `BaseDocumentStream`: `codec`, `documents`, `factory`, `filterRe`, `format`, `length`, `locations`, `schema`, `stream`, `streamLocation`

Method Details

### parse_url(self, url) | source code